[−][src]Module wiremock::matchers
A collection of different matching strategies provided out-of-the-box by wiremock.
If the set of matchers provided out-of-the-box is not enough for your specific testing needs
you can implement your own thanks to the Match trait.
Furthermore, Fn closures that take an immutable Request reference as input and return a boolean
as input automatically implement Match and can be used where a matcher is expected.
Check Match's documentation for examples.
Structs
| BodyExactMatcher | Match exactly the body of a request. |
| HeaderExactMatcher | Match exactly the header of a request. |
| MethodExactMatcher | Match exactly the method of a request. |
| PathExactMatcher | Match exactly the path of a request. |
| QueryParamExactMatcher | Match exactly the query parameter of a request. |
Functions
| body_bytes | Shorthand for |
| body_json | Shorthand for |
| body_string | Shorthand for |
| header | Shorthand for |
| method | Shorthand for |
| path | Shorthand for |
| query_param | Shorthand for |